mount

Function mount 

pub fn mount<FS: Filesystem, P: AsRef<Path>>(
    filesystem: FS,
    mountpoint: P,
    options: &Config,
) -> Result<()>
Mount the given filesystem to the given mountpoint. This function will not return until the filesystem is unmounted.

NOTE: This will eventually replace mount(), once the API is stable

Errors

Returns an error if the options are incorrect, or if the fuse device can’t be mounted, and any final error when the session comes to an end.