Module lib_async

Module lib_async 

Experimental Asynchronous API for fuser. This is gated behind the “async” feature, and is not yet considered stable. The API may change without a major version bump.

Traits

AsyncFilesystem
Async filesystem trait. This is the async version of crate::Filesystem. It follows a more Rust-idiomatic async API design rather than the C-like, callback-based interface used by crate::Filesystem. It is not intended to be a thin wrapper over that API.

Functions

mount_async
Mount the given async filesystem to the given mountpoint. This function will not return until the filesystem is unmounted.