pub struct ReadResponse { /* private fields */ }Expand description
Response data from crate::AsyncFilesystem::read operation
Implementations
Sourceimpl ReadResponse
impl ReadResponse
Sourcepub fn new(data: Vec<u8>) -> ReadResponse
pub fn new(data: Vec<u8>) -> ReadResponse
Creates a new ReadResponse with a specified buffer.
Creates a ReadResponse backed by a slice of shared data without copying it.
The requested range is clamped to the bounds of data.