AsyncSession

Struct AsyncSession 

pub struct AsyncSession<FS: AsyncFilesystem> { /* private fields */ }
The async session data structure

Implementations

Source

impl<FS: AsyncFilesystem> AsyncSession<FS>

pub async fn run(self) -> Result<()>

Run the session async loop that receives kernel requests and dispatches them to method calls into the filesystem.

Errors

Returns any final error when the session comes to an end.