Experimental Asynchronous API for fuser. This is gated behind the “async” feature, and is not yet considered stable. The API may change without a major version bump.
Traits
- Async
Filesystem - Async filesystem trait. This is the async version of
crate::Filesystem. It follows a more Rust-idiomatic async API design rather than the C-like, callback-based interface used bycrate::Filesystem. It is not intended to be a thin wrapper over that API.
Functions
- mount_
async - Mount the given async filesystem to the given mountpoint. This function will not return until the filesystem is unmounted.