pub async fn mount_async<FS: AsyncFilesystem, P: AsRef<Path>>(
filesystem: FS,
mountpoint: P,
options: &Config,
) -> Result<()>Expand description
Mount the given async filesystem to the given mountpoint. This function will not return until the filesystem is unmounted.
Errors
Returns an error if the options are incorrect, or if the fuse device can’t be mounted, and any final error when the session comes to an end.