pub struct DirectoryResponse { /* private fields */ }Expand description
Response data from crate::AsyncFilesystem::readdir operation
Implementations
Sourceimpl DirectoryResponse
impl DirectoryResponse
Sourcepub fn new(size: usize) -> DirectoryResponse
pub fn new(size: usize) -> DirectoryResponse
Creates a new DirectoryResponse with a specified buffer size.
Sourcepub fn add<T: AsRef<OsStr>>(
&mut self,
ino: INodeNo,
offset: u64,
kind: FileType,
name: T,
) -> bool
pub fn add<T: AsRef<OsStr>>( &mut self, ino: INodeNo, offset: u64, kind: FileType, name: T, ) -> bool
Add an entry to the directory reply buffer. Returns true if the buffer is full. A transparent offset value can be provided for each entry. The kernel uses these value to request the next entries in further readdir calls